Class: Enums::DistanceTypes

Inherits:
Object
  • Object
show all
Defined in:
lib/enums/distance_types.rb

Overview

Enumerator class for type of measurement of geo distance.

Class Method Summary collapse

Class Method Details

.arcDistanceTypes

default type



# File 'lib/enums/distance_types.rb', line 19


.planeDistanceTypes

faster, but inaccurate on long distances and close to the poles



# File 'lib/enums/distance_types.rb', line 25