Class: Enums::ZeroTermsQuery

Inherits:
Object
  • Object
show all
Defined in:
lib/enums/zero_terms_query.rb

Overview

Enumerator class for zer terms query. If the analyzer used removes all tokens in a query like a stop filter does, the default behavior is to match no documents at all. In order to change that the zero_terms_query option can be used, which accepts none (default) and all which corresponds to a match_all query.

Class Method Summary collapse

Class Method Details

.allValidationMethods



# File 'lib/enums/zero_terms_query.rb', line 22


.noneValidationMethods



# File 'lib/enums/zero_terms_query.rb', line 27